# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from osmosis.lockup import query_pb2 as osmosis_dot_lockup_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ModuleBalance = channel.unary_unary(
                '/osmosis.lockup.Query/ModuleBalance',
                request_serializer=osmosis_dot_lockup_dot_query__pb2.ModuleBalanceRequest.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_query__pb2.ModuleBalanceResponse.FromString,
                )
        self.ModuleLockedAmount = channel.unary_unary(
                '/osmosis.lockup.Query/ModuleLockedAmount',
                request_serializer=osmosis_dot_lockup_dot_query__pb2.ModuleLockedAmountRequest.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_query__pb2.ModuleLockedAmountResponse.FromString,
                )
        self.AccountUnlockableCoins = channel.unary_unary(
                '/osmosis.lockup.Query/AccountUnlockableCoins',
                request_serializer=osmosis_dot_lockup_dot_query__pb2.AccountUnlockableCoinsRequest.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountUnlockableCoinsResponse.FromString,
                )
        self.AccountUnlockingCoins = channel.unary_unary(
                '/osmosis.lockup.Query/AccountUnlockingCoins',
                request_serializer=osmosis_dot_lockup_dot_query__pb2.AccountUnlockingCoinsRequest.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountUnlockingCoinsResponse.FromString,
                )
        self.AccountLockedCoins = channel.unary_unary(
                '/osmosis.lockup.Query/AccountLockedCoins',
                request_serializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedCoinsRequest.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedCoinsResponse.FromString,
                )
        self.AccountLockedPastTime = channel.unary_unary(
                '/osmosis.lockup.Query/AccountLockedPastTime',
                request_serializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeRequest.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeResponse.FromString,
                )
        self.AccountLockedPastTimeNotUnlockingOnly = channel.unary_unary(
                '/osmosis.lockup.Query/AccountLockedPastTimeNotUnlockingOnly',
                request_serializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeNotUnlockingOnlyRequest.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeNotUnlockingOnlyResponse.FromString,
                )
        self.AccountUnlockedBeforeTime = channel.unary_unary(
                '/osmosis.lockup.Query/AccountUnlockedBeforeTime',
                request_serializer=osmosis_dot_lockup_dot_query__pb2.AccountUnlockedBeforeTimeRequest.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountUnlockedBeforeTimeResponse.FromString,
                )
        self.AccountLockedPastTimeDenom = channel.unary_unary(
                '/osmosis.lockup.Query/AccountLockedPastTimeDenom',
                request_serializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeDenomRequest.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeDenomResponse.FromString,
                )
        self.LockedDenom = channel.unary_unary(
                '/osmosis.lockup.Query/LockedDenom',
                request_serializer=osmosis_dot_lockup_dot_query__pb2.LockedDenomRequest.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_query__pb2.LockedDenomResponse.FromString,
                )
        self.LockedByID = channel.unary_unary(
                '/osmosis.lockup.Query/LockedByID',
                request_serializer=osmosis_dot_lockup_dot_query__pb2.LockedRequest.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_query__pb2.LockedResponse.FromString,
                )
        self.SyntheticLockupsByLockupID = channel.unary_unary(
                '/osmosis.lockup.Query/SyntheticLockupsByLockupID',
                request_serializer=osmosis_dot_lockup_dot_query__pb2.SyntheticLockupsByLockupIDRequest.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_query__pb2.SyntheticLockupsByLockupIDResponse.FromString,
                )
        self.AccountLockedLongerDuration = channel.unary_unary(
                '/osmosis.lockup.Query/AccountLockedLongerDuration',
                request_serializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationRequest.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationResponse.FromString,
                )
        self.AccountLockedDuration = channel.unary_unary(
                '/osmosis.lockup.Query/AccountLockedDuration',
                request_serializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedDurationRequest.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedDurationResponse.FromString,
                )
        self.AccountLockedLongerDurationNotUnlockingOnly = channel.unary_unary(
                '/osmosis.lockup.Query/AccountLockedLongerDurationNotUnlockingOnly',
                request_serializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationNotUnlockingOnlyRequest.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationNotUnlockingOnlyResponse.FromString,
                )
        self.AccountLockedLongerDurationDenom = channel.unary_unary(
                '/osmosis.lockup.Query/AccountLockedLongerDurationDenom',
                request_serializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationDenomRequest.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationDenomResponse.FromString,
                )
        self.Params = channel.unary_unary(
                '/osmosis.lockup.Query/Params',
                request_serializer=osmosis_dot_lockup_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=osmosis_dot_lockup_dot_query__pb2.QueryParamsResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def ModuleBalance(self, request, context):
        """Return full balance of the module
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModuleLockedAmount(self, request, context):
        """Return locked balance of the module
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccountUnlockableCoins(self, request, context):
        """Returns unlockable coins which are not withdrawn yet
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccountUnlockingCoins(self, request, context):
        """Returns unlocking coins
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccountLockedCoins(self, request, context):
        """Return a locked coins that can't be withdrawn
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccountLockedPastTime(self, request, context):
        """Returns locked records of an account with unlock time beyond timestamp
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccountLockedPastTimeNotUnlockingOnly(self, request, context):
        """Returns locked records of an account with unlock time beyond timestamp
        excluding tokens started unlocking
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccountUnlockedBeforeTime(self, request, context):
        """Returns unlocked records with unlock time before timestamp
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccountLockedPastTimeDenom(self, request, context):
        """Returns lock records by address, timestamp, denom
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LockedDenom(self, request, context):
        """Returns total locked per denom with longer past given time
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LockedByID(self, request, context):
        """Returns lock record by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SyntheticLockupsByLockupID(self, request, context):
        """Returns synthetic lockups by native lockup id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccountLockedLongerDuration(self, request, context):
        """Returns account locked records with longer duration
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccountLockedDuration(self, request, context):
        """Returns account locked records with a specific duration
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccountLockedLongerDurationNotUnlockingOnly(self, request, context):
        """Returns account locked records with longer duration excluding tokens
        started unlocking
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccountLockedLongerDurationDenom(self, request, context):
        """Returns account's locked records for a denom with longer duration
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        """Params returns lockup params.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ModuleBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.ModuleBalance,
                    request_deserializer=osmosis_dot_lockup_dot_query__pb2.ModuleBalanceRequest.FromString,
                    response_serializer=osmosis_dot_lockup_dot_query__pb2.ModuleBalanceResponse.SerializeToString,
            ),
            'ModuleLockedAmount': grpc.unary_unary_rpc_method_handler(
                    servicer.ModuleLockedAmount,
                    request_deserializer=osmosis_dot_lockup_dot_query__pb2.ModuleLockedAmountRequest.FromString,
                    response_serializer=osmosis_dot_lockup_dot_query__pb2.ModuleLockedAmountResponse.SerializeToString,
            ),
            'AccountUnlockableCoins': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountUnlockableCoins,
                    request_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountUnlockableCoinsRequest.FromString,
                    response_serializer=osmosis_dot_lockup_dot_query__pb2.AccountUnlockableCoinsResponse.SerializeToString,
            ),
            'AccountUnlockingCoins': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountUnlockingCoins,
                    request_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountUnlockingCoinsRequest.FromString,
                    response_serializer=osmosis_dot_lockup_dot_query__pb2.AccountUnlockingCoinsResponse.SerializeToString,
            ),
            'AccountLockedCoins': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountLockedCoins,
                    request_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedCoinsRequest.FromString,
                    response_serializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedCoinsResponse.SerializeToString,
            ),
            'AccountLockedPastTime': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountLockedPastTime,
                    request_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeRequest.FromString,
                    response_serializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeResponse.SerializeToString,
            ),
            'AccountLockedPastTimeNotUnlockingOnly': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountLockedPastTimeNotUnlockingOnly,
                    request_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeNotUnlockingOnlyRequest.FromString,
                    response_serializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeNotUnlockingOnlyResponse.SerializeToString,
            ),
            'AccountUnlockedBeforeTime': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountUnlockedBeforeTime,
                    request_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountUnlockedBeforeTimeRequest.FromString,
                    response_serializer=osmosis_dot_lockup_dot_query__pb2.AccountUnlockedBeforeTimeResponse.SerializeToString,
            ),
            'AccountLockedPastTimeDenom': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountLockedPastTimeDenom,
                    request_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeDenomRequest.FromString,
                    response_serializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeDenomResponse.SerializeToString,
            ),
            'LockedDenom': grpc.unary_unary_rpc_method_handler(
                    servicer.LockedDenom,
                    request_deserializer=osmosis_dot_lockup_dot_query__pb2.LockedDenomRequest.FromString,
                    response_serializer=osmosis_dot_lockup_dot_query__pb2.LockedDenomResponse.SerializeToString,
            ),
            'LockedByID': grpc.unary_unary_rpc_method_handler(
                    servicer.LockedByID,
                    request_deserializer=osmosis_dot_lockup_dot_query__pb2.LockedRequest.FromString,
                    response_serializer=osmosis_dot_lockup_dot_query__pb2.LockedResponse.SerializeToString,
            ),
            'SyntheticLockupsByLockupID': grpc.unary_unary_rpc_method_handler(
                    servicer.SyntheticLockupsByLockupID,
                    request_deserializer=osmosis_dot_lockup_dot_query__pb2.SyntheticLockupsByLockupIDRequest.FromString,
                    response_serializer=osmosis_dot_lockup_dot_query__pb2.SyntheticLockupsByLockupIDResponse.SerializeToString,
            ),
            'AccountLockedLongerDuration': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountLockedLongerDuration,
                    request_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationRequest.FromString,
                    response_serializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationResponse.SerializeToString,
            ),
            'AccountLockedDuration': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountLockedDuration,
                    request_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedDurationRequest.FromString,
                    response_serializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedDurationResponse.SerializeToString,
            ),
            'AccountLockedLongerDurationNotUnlockingOnly': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountLockedLongerDurationNotUnlockingOnly,
                    request_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationNotUnlockingOnlyRequest.FromString,
                    response_serializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationNotUnlockingOnlyResponse.SerializeToString,
            ),
            'AccountLockedLongerDurationDenom': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountLockedLongerDurationDenom,
                    request_deserializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationDenomRequest.FromString,
                    response_serializer=osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationDenomResponse.SerializeToString,
            ),
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=osmosis_dot_lockup_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=osmosis_dot_lockup_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'osmosis.lockup.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def ModuleBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Query/ModuleBalance',
            osmosis_dot_lockup_dot_query__pb2.ModuleBalanceRequest.SerializeToString,
            osmosis_dot_lockup_dot_query__pb2.ModuleBalanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ModuleLockedAmount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Query/ModuleLockedAmount',
            osmosis_dot_lockup_dot_query__pb2.ModuleLockedAmountRequest.SerializeToString,
            osmosis_dot_lockup_dot_query__pb2.ModuleLockedAmountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AccountUnlockableCoins(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Query/AccountUnlockableCoins',
            osmosis_dot_lockup_dot_query__pb2.AccountUnlockableCoinsRequest.SerializeToString,
            osmosis_dot_lockup_dot_query__pb2.AccountUnlockableCoinsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AccountUnlockingCoins(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Query/AccountUnlockingCoins',
            osmosis_dot_lockup_dot_query__pb2.AccountUnlockingCoinsRequest.SerializeToString,
            osmosis_dot_lockup_dot_query__pb2.AccountUnlockingCoinsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AccountLockedCoins(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Query/AccountLockedCoins',
            osmosis_dot_lockup_dot_query__pb2.AccountLockedCoinsRequest.SerializeToString,
            osmosis_dot_lockup_dot_query__pb2.AccountLockedCoinsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AccountLockedPastTime(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Query/AccountLockedPastTime',
            osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeRequest.SerializeToString,
            osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AccountLockedPastTimeNotUnlockingOnly(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Query/AccountLockedPastTimeNotUnlockingOnly',
            osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeNotUnlockingOnlyRequest.SerializeToString,
            osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeNotUnlockingOnlyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AccountUnlockedBeforeTime(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Query/AccountUnlockedBeforeTime',
            osmosis_dot_lockup_dot_query__pb2.AccountUnlockedBeforeTimeRequest.SerializeToString,
            osmosis_dot_lockup_dot_query__pb2.AccountUnlockedBeforeTimeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AccountLockedPastTimeDenom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Query/AccountLockedPastTimeDenom',
            osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeDenomRequest.SerializeToString,
            osmosis_dot_lockup_dot_query__pb2.AccountLockedPastTimeDenomResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LockedDenom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Query/LockedDenom',
            osmosis_dot_lockup_dot_query__pb2.LockedDenomRequest.SerializeToString,
            osmosis_dot_lockup_dot_query__pb2.LockedDenomResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LockedByID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Query/LockedByID',
            osmosis_dot_lockup_dot_query__pb2.LockedRequest.SerializeToString,
            osmosis_dot_lockup_dot_query__pb2.LockedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SyntheticLockupsByLockupID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Query/SyntheticLockupsByLockupID',
            osmosis_dot_lockup_dot_query__pb2.SyntheticLockupsByLockupIDRequest.SerializeToString,
            osmosis_dot_lockup_dot_query__pb2.SyntheticLockupsByLockupIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AccountLockedLongerDuration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Query/AccountLockedLongerDuration',
            osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationRequest.SerializeToString,
            osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AccountLockedDuration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Query/AccountLockedDuration',
            osmosis_dot_lockup_dot_query__pb2.AccountLockedDurationRequest.SerializeToString,
            osmosis_dot_lockup_dot_query__pb2.AccountLockedDurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AccountLockedLongerDurationNotUnlockingOnly(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Query/AccountLockedLongerDurationNotUnlockingOnly',
            osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationNotUnlockingOnlyRequest.SerializeToString,
            osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationNotUnlockingOnlyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AccountLockedLongerDurationDenom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Query/AccountLockedLongerDurationDenom',
            osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationDenomRequest.SerializeToString,
            osmosis_dot_lockup_dot_query__pb2.AccountLockedLongerDurationDenomResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.lockup.Query/Params',
            osmosis_dot_lockup_dot_query__pb2.QueryParamsRequest.SerializeToString,
            osmosis_dot_lockup_dot_query__pb2.QueryParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
The network class allows the user to defines the network the sdk interface should connect to.

There are some default values set for devnet, testnet, mainet and localnet, but the user cna also define its own
network by setting the values of the Network data class.

"""
import dataclasses
import enum
import os
from typing import Dict, List, Optional


class NetworkType(enum.Enum):
    """Enum class for the available network types. E.g. 'testnet' and 'devnet'."""

    DEVNET = "devnet"
    TESTNET = "testnet"
    LOCALNET = "localnet"


@dataclasses.dataclass
class Network:
    lcd_endpoint: str
    grpc_endpoint: str
    tendermint_rpc_endpoint: str
    chain_id: str
    env: str = "custom"

    @property
    def is_insecure(self) -> bool:
        return not ("https" in self.tendermint_rpc_endpoint)

    @classmethod
    def devnet(cls) -> "Network":
        """
        **NOT IMPLEMENTED YET**
        """
        raise NotImplementedError

    @classmethod
    def testnet(cls) -> "Network":
        """
        **NOT IMPLEMENTED YET**
        """
        raise NotImplementedError

    @classmethod
    def mainnet(cls) -> "Network":
        return cls(
            lcd_endpoint=f'https://lcd.osmosis.zone',
            grpc_endpoint=f'grpc.osmosis.zone:9090',
            tendermint_rpc_endpoint=f'https://rpc.osmosis.zone:443',
            chain_id=f'osmosis-1',
            env=NetworkType.MAINNET.value,
        )

    @classmethod
    def localnet(cls) -> "Network":
        """
        Localnet is the network you would expect to connect to if you run `make localnet` from the osmosis repository.
        It allows you to update locally the golang codebase to checkout the behavior of the chain with different changes
        applied.

        Returns:
            Network: The updated Network object.
        """
        return cls(
            lcd_endpoint=f'http://localhost:1317',
            grpc_endpoint=f'localhost:9090',
            tendermint_rpc_endpoint=f'http://localhost:26657	',
            chain_id=f'osmosis-1',
            env=NetworkType.LOCALNET.value,
        )

    def string(self) -> str:
        """
        Returns the current environment the network was initialized with. Will return `custom` if a custom network
        was created

        Returns:
            str: The name of the current environment.
        """
        return self.env



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MsgSuperfluidDelegate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    LOCK_ID_FIELD_NUMBER: builtins.int
    VAL_ADDR_FIELD_NUMBER: builtins.int
    sender: builtins.str
    lock_id: builtins.int
    val_addr: builtins.str
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        lock_id: builtins.int = ...,
        val_addr: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lock_id", b"lock_id", "sender", b"sender", "val_addr", b"val_addr"]) -> None: ...

global___MsgSuperfluidDelegate = MsgSuperfluidDelegate

@typing_extensions.final
class MsgSuperfluidDelegateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgSuperfluidDelegateResponse = MsgSuperfluidDelegateResponse

@typing_extensions.final
class MsgSuperfluidUndelegate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    LOCK_ID_FIELD_NUMBER: builtins.int
    sender: builtins.str
    lock_id: builtins.int
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        lock_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lock_id", b"lock_id", "sender", b"sender"]) -> None: ...

global___MsgSuperfluidUndelegate = MsgSuperfluidUndelegate

@typing_extensions.final
class MsgSuperfluidUndelegateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgSuperfluidUndelegateResponse = MsgSuperfluidUndelegateResponse

@typing_extensions.final
class MsgSuperfluidUnbondLock(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    LOCK_ID_FIELD_NUMBER: builtins.int
    sender: builtins.str
    lock_id: builtins.int
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        lock_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lock_id", b"lock_id", "sender", b"sender"]) -> None: ...

global___MsgSuperfluidUnbondLock = MsgSuperfluidUnbondLock

@typing_extensions.final
class MsgSuperfluidUnbondLockResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgSuperfluidUnbondLockResponse = MsgSuperfluidUnbondLockResponse

@typing_extensions.final
class MsgLockAndSuperfluidDelegate(google.protobuf.message.Message):
    """message MsgSuperfluidRedelegate {
      string sender = 1 [ (gogoproto.moretags) = "yaml:\\"sender\\"" ];
      uint64 lock_id = 2;
      string new_val_addr = 3;
    }
    message MsgSuperfluidRedelegateResponse {}

    MsgLockAndSuperfluidDelegate locks coins with the unbonding period duration,
    and then does a superfluid lock from the newly created lockup, to the
    specified validator addr.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    COINS_FIELD_NUMBER: builtins.int
    VAL_ADDR_FIELD_NUMBER: builtins.int
    sender: builtins.str
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    val_addr: builtins.str
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        val_addr: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["coins", b"coins", "sender", b"sender", "val_addr", b"val_addr"]) -> None: ...

global___MsgLockAndSuperfluidDelegate = MsgLockAndSuperfluidDelegate

@typing_extensions.final
class MsgLockAndSuperfluidDelegateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ID: builtins.int
    def __init__(
        self,
        *,
        ID: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ID", b"ID"]) -> None: ...

global___MsgLockAndSuperfluidDelegateResponse = MsgLockAndSuperfluidDelegateResponse

@typing_extensions.final
class MsgUnPoolWhitelistedPool(google.protobuf.message.Message):
    """MsgUnPoolWhitelistedPool Unpools every lock the sender has, that is
    associated with pool pool_id. If pool_id is not approved for unpooling by
    governance, this is a no-op. Unpooling takes the locked gamm shares, and runs
    "ExitPool" on it, to get the constituent tokens. e.g. z gamm/pool/1 tokens
    ExitPools into constituent tokens x uatom, y uosmo. Then it creates a new
    lock for every constituent token, with the duration associated with the lock.
    If the lock was unbonding, the new lockup durations should be the time left
    until unbond completion.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    sender: builtins.str
    pool_id: builtins.int
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        pool_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id", "sender", b"sender"]) -> None: ...

global___MsgUnPoolWhitelistedPool = MsgUnPoolWhitelistedPool

@typing_extensions.final
class MsgUnPoolWhitelistedPoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXITED_LOCK_IDS_FIELD_NUMBER: builtins.int
    @property
    def exited_lock_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        exited_lock_ids: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exited_lock_ids", b"exited_lock_ids"]) -> None: ...

global___MsgUnPoolWhitelistedPoolResponse = MsgUnPoolWhitelistedPoolResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Coin(google.protobuf.message.Message):
    """Coin defines a token with a denomination and an amount.

    NOTE: The amount field is an Int which implements the custom method
    signatures required by gogoproto.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    denom: builtins.str
    amount: builtins.str
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
        amount: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "denom", b"denom"]) -> None: ...

global___Coin = Coin

@typing_extensions.final
class DecCoin(google.protobuf.message.Message):
    """DecCoin defines a token with a denomination and a decimal amount.

    NOTE: The amount field is an Dec which implements the custom method
    signatures required by gogoproto.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    denom: builtins.str
    amount: builtins.str
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
        amount: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "denom", b"denom"]) -> None: ...

global___DecCoin = DecCoin

@typing_extensions.final
class IntProto(google.protobuf.message.Message):
    """IntProto defines a Protobuf wrapper around an Int object."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INT_FIELD_NUMBER: builtins.int
    int: builtins.str
    def __init__(
        self,
        *,
        int: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["int", b"int"]) -> None: ...

global___IntProto = IntProto

@typing_extensions.final
class DecProto(google.protobuf.message.Message):
    """DecProto defines a Protobuf wrapper around a Dec object."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEC_FIELD_NUMBER: builtins.int
    dec: builtins.str
    def __init__(
        self,
        *,
        dec: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dec", b"dec"]) -> None: ...

global___DecProto = DecProto



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.mint.v1beta1.query_pb2

class QueryStub:
    """Query provides defines the gRPC querier service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    Params: grpc.UnaryUnaryMultiCallable[
        osmosis.mint.v1beta1.query_pb2.QueryParamsRequest,
        osmosis.mint.v1beta1.query_pb2.QueryParamsResponse,
    ]
    """Params returns the total set of minting parameters."""
    EpochProvisions: grpc.UnaryUnaryMultiCallable[
        osmosis.mint.v1beta1.query_pb2.QueryEpochProvisionsRequest,
        osmosis.mint.v1beta1.query_pb2.QueryEpochProvisionsResponse,
    ]
    """EpochProvisions returns the current minting epoch provisions value."""

class QueryServicer(metaclass=abc.ABCMeta):
    """Query provides defines the gRPC querier service."""

    @abc.abstractmethod
    def Params(
        self,
        request: osmosis.mint.v1beta1.query_pb2.QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.mint.v1beta1.query_pb2.QueryParamsResponse:
        """Params returns the total set of minting parameters."""
    @abc.abstractmethod
    def EpochProvisions(
        self,
        request: osmosis.mint.v1beta1.query_pb2.QueryEpochProvisionsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.mint.v1beta1.query_pb2.QueryEpochProvisionsResponse:
        """EpochProvisions returns the current minting epoch provisions value."""

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class PubKey(google.protobuf.message.Message):
    """PubKey is an ed25519 public key for handling Tendermint keys in SDK.
    It's needed for Any serialization and SDK compatibility.
    It must not be used in a non Tendermint key context because it doesn't implement
    ADR-28. Nevertheless, you will like to use ed25519 in app user level
    then you must create a new proto message and follow ADR-28 for Address construction.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    key: builtins.bytes
    def __init__(
        self,
        *,
        key: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key"]) -> None: ...

global___PubKey = PubKey

@typing_extensions.final
class PrivKey(google.protobuf.message.Message):
    """Deprecated: PrivKey defines a ed25519 private key.
    NOTE: ed25519 keys must not be used in SDK apps except in a tendermint validator context.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    key: builtins.bytes
    def __init__(
        self,
        *,
        key: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key"]) -> None: ...

global___PrivKey = PrivKey



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Since: cosmos-sdk 0.43"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenericAuthorization(google.protobuf.message.Message):
    """GenericAuthorization gives the grantee unrestricted permissions to execute
    the provided method on behalf of the granter's account.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    """Msg, identified by it's type URL, to grant unrestricted permissions to execute"""
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg", b"msg"]) -> None: ...

global___GenericAuthorization = GenericAuthorization

@typing_extensions.final
class Grant(google.protobuf.message.Message):
    """Grant gives permissions to execute
    the provide method with expiration time.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHORIZATION_FIELD_NUMBER: builtins.int
    EXPIRATION_FIELD_NUMBER: builtins.int
    @property
    def authorization(self) -> google.protobuf.any_pb2.Any: ...
    @property
    def expiration(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        authorization: google.protobuf.any_pb2.Any | None = ...,
        expiration: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authorization", b"authorization", "expiration", b"expiration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorization", b"authorization", "expiration", b"expiration"]) -> None: ...

global___Grant = Grant



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.tokenfactory.v1beta1.authorityMetadata_pb2
import osmosis.tokenfactory.v1beta1.params_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the tokenfactory module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    FACTORY_DENOMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> osmosis.tokenfactory.v1beta1.params_pb2.Params:
        """params defines the paramaters of the module."""
    @property
    def factory_denoms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GenesisDenom]: ...
    def __init__(
        self,
        *,
        params: osmosis.tokenfactory.v1beta1.params_pb2.Params | None = ...,
        factory_denoms: collections.abc.Iterable[global___GenesisDenom] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["factory_denoms", b"factory_denoms", "params", b"params"]) -> None: ...

global___GenesisState = GenesisState

@typing_extensions.final
class GenesisDenom(google.protobuf.message.Message):
    """GenesisDenom defines a tokenfactory denom that is defined within genesis
    state. The structure contains DenomAuthorityMetadata which defines the
    denom's admin.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    AUTHORITY_METADATA_FIELD_NUMBER: builtins.int
    denom: builtins.str
    @property
    def authority_metadata(self) -> osmosis.tokenfactory.v1beta1.authorityMetadata_pb2.DenomAuthorityMetadata: ...
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
        authority_metadata: osmosis.tokenfactory.v1beta1.authorityMetadata_pb2.DenomAuthorityMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authority_metadata", b"authority_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authority_metadata", b"authority_metadata", "denom", b"denom"]) -> None: ...

global___GenesisDenom = GenesisDenom



# These import statements export the types to 'osmosispy.pytypes'.

from osmosispy.pytypes.common import (  # noqa # TODO move constants to a constants.py file.; noqa
    GAS_PRICE,
    MAX_MEMO_CHARACTERS,
    Coin,
    Direction,
    PoolAsset,
    PythonMsg,
    Side,
    TxConfig,
    TxType,
)
from osmosispy.pytypes.event import Event, RawEvent, TxLogEvents  # noqa
from osmosispy.pytypes.network import Network, NetworkType  # noqa
from osmosispy.pytypes.tx_resp import RawTxResp, TxResp  # noqa



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Since: cosmos-sdk 0.43"""
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the authz module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHORIZATION_FIELD_NUMBER: builtins.int
    @property
    def authorization(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GrantAuthorization]: ...
    def __init__(
        self,
        *,
        authorization: collections.abc.Iterable[global___GrantAuthorization] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorization", b"authorization"]) -> None: ...

global___GenesisState = GenesisState

@typing_extensions.final
class GrantAuthorization(google.protobuf.message.Message):
    """GrantAuthorization defines the GenesisState/GrantAuthorization type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    AUTHORIZATION_FIELD_NUMBER: builtins.int
    EXPIRATION_FIELD_NUMBER: builtins.int
    granter: builtins.str
    grantee: builtins.str
    @property
    def authorization(self) -> google.protobuf.any_pb2.Any: ...
    @property
    def expiration(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        granter: builtins.str = ...,
        grantee: builtins.str = ...,
        authorization: google.protobuf.any_pb2.Any | None = ...,
        expiration: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authorization", b"authorization", "expiration", b"expiration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorization", b"authorization", "expiration", b"expiration", "grantee", b"grantee", "granter", b"granter"]) -> None: ...

global___GrantAuthorization = GrantAuthorization



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/auth/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google_apis.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/auth/v1beta1/query.proto\x12\x13\x63osmos.auth.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x63osmos/auth/v1beta1/auth.proto\x1a\x19\x63osmos_proto/cosmos.proto\"R\n\x14QueryAccountsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8a\x01\n\x15QueryAccountsResponse\x12\x34\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyB\x0c\xca\xb4-\x08\x41\x63\x63ountI\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"0\n\x13QueryAccountRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"K\n\x14QueryAccountResponse\x12\x33\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x0c\xca\xb4-\x08\x41\x63\x63ountI\"\x14\n\x12QueryParamsRequest\"H\n\x13QueryParamsResponse\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32\x1b.cosmos.auth.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\"\x1c\n\x1aQueryModuleAccountsRequest\"Y\n\x1bQueryModuleAccountsResponse\x12:\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyB\x12\xca\xb4-\x0eModuleAccountI2\xcb\x04\n\x05Query\x12\x88\x01\n\x08\x41\x63\x63ounts\x12).cosmos.auth.v1beta1.QueryAccountsRequest\x1a*.cosmos.auth.v1beta1.QueryAccountsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/auth/v1beta1/accounts\x12\x8f\x01\n\x07\x41\x63\x63ount\x12(.cosmos.auth.v1beta1.QueryAccountRequest\x1a).cosmos.auth.v1beta1.QueryAccountResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/cosmos/auth/v1beta1/accounts/{address}\x12\x80\x01\n\x06Params\x12\'.cosmos.auth.v1beta1.QueryParamsRequest\x1a(.cosmos.auth.v1beta1.QueryParamsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/auth/v1beta1/params\x12\xa1\x01\n\x0eModuleAccounts\x12/.cosmos.auth.v1beta1.QueryModuleAccountsRequest\x1a\x30.cosmos.auth.v1beta1.QueryModuleAccountsResponse\",\x82\xd3\xe4\x93\x02&\x12$/cosmos/auth/v1beta1/module_accountsB+Z)github.com/cosmos/cosmos-sdk/x/auth/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.auth.v1beta1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/auth/types'
  _QUERYACCOUNTSRESPONSE.fields_by_name['accounts']._options = None
  _QUERYACCOUNTSRESPONSE.fields_by_name['accounts']._serialized_options = b'\312\264-\010AccountI'
  _QUERYACCOUNTREQUEST._options = None
  _QUERYACCOUNTREQUEST._serialized_options = b'\350\240\037\000\210\240\037\000'
  _QUERYACCOUNTRESPONSE.fields_by_name['account']._options = None
  _QUERYACCOUNTRESPONSE.fields_by_name['account']._serialized_options = b'\312\264-\010AccountI'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYMODULEACCOUNTSRESPONSE.fields_by_name['accounts']._options = None
  _QUERYMODULEACCOUNTSRESPONSE.fields_by_name['accounts']._serialized_options = b'\312\264-\016ModuleAccountI'
  _QUERY.methods_by_name['Accounts']._options = None
  _QUERY.methods_by_name['Accounts']._serialized_options = b'\202\323\344\223\002\037\022\035/cosmos/auth/v1beta1/accounts'
  _QUERY.methods_by_name['Account']._options = None
  _QUERY.methods_by_name['Account']._serialized_options = b'\202\323\344\223\002)\022\'/cosmos/auth/v1beta1/accounts/{address}'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\035\022\033/cosmos/auth/v1beta1/params'
  _QUERY.methods_by_name['ModuleAccounts']._options = None
  _QUERY.methods_by_name['ModuleAccounts']._serialized_options = b'\202\323\344\223\002&\022$/cosmos/auth/v1beta1/module_accounts'
  _QUERYACCOUNTSREQUEST._serialized_start=238
  _QUERYACCOUNTSREQUEST._serialized_end=320
  _QUERYACCOUNTSRESPONSE._serialized_start=323
  _QUERYACCOUNTSRESPONSE._serialized_end=461
  _QUERYACCOUNTREQUEST._serialized_start=463
  _QUERYACCOUNTREQUEST._serialized_end=511
  _QUERYACCOUNTRESPONSE._serialized_start=513
  _QUERYACCOUNTRESPONSE._serialized_end=588
  _QUERYPARAMSREQUEST._serialized_start=590
  _QUERYPARAMSREQUEST._serialized_end=610
  _QUERYPARAMSRESPONSE._serialized_start=612
  _QUERYPARAMSRESPONSE._serialized_end=684
  _QUERYMODULEACCOUNTSREQUEST._serialized_start=686
  _QUERYMODULEACCOUNTSREQUEST._serialized_end=714
  _QUERYMODULEACCOUNTSRESPONSE._serialized_start=716
  _QUERYMODULEACCOUNTSRESPONSE._serialized_end=805
  _QUERY._serialized_start=808
  _QUERY._serialized_end=1395
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from osmosis.incentives import query_pb2 as osmosis_dot_incentives_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ModuleToDistributeCoins = channel.unary_unary(
                '/osmosis.incentives.Query/ModuleToDistributeCoins',
                request_serializer=osmosis_dot_incentives_dot_query__pb2.ModuleToDistributeCoinsRequest.SerializeToString,
                response_deserializer=osmosis_dot_incentives_dot_query__pb2.ModuleToDistributeCoinsResponse.FromString,
                )
        self.GaugeByID = channel.unary_unary(
                '/osmosis.incentives.Query/GaugeByID',
                request_serializer=osmosis_dot_incentives_dot_query__pb2.GaugeByIDRequest.SerializeToString,
                response_deserializer=osmosis_dot_incentives_dot_query__pb2.GaugeByIDResponse.FromString,
                )
        self.Gauges = channel.unary_unary(
                '/osmosis.incentives.Query/Gauges',
                request_serializer=osmosis_dot_incentives_dot_query__pb2.GaugesRequest.SerializeToString,
                response_deserializer=osmosis_dot_incentives_dot_query__pb2.GaugesResponse.FromString,
                )
        self.ActiveGauges = channel.unary_unary(
                '/osmosis.incentives.Query/ActiveGauges',
                request_serializer=osmosis_dot_incentives_dot_query__pb2.ActiveGaugesRequest.SerializeToString,
                response_deserializer=osmosis_dot_incentives_dot_query__pb2.ActiveGaugesResponse.FromString,
                )
        self.ActiveGaugesPerDenom = channel.unary_unary(
                '/osmosis.incentives.Query/ActiveGaugesPerDenom',
                request_serializer=osmosis_dot_incentives_dot_query__pb2.ActiveGaugesPerDenomRequest.SerializeToString,
                response_deserializer=osmosis_dot_incentives_dot_query__pb2.ActiveGaugesPerDenomResponse.FromString,
                )
        self.UpcomingGauges = channel.unary_unary(
                '/osmosis.incentives.Query/UpcomingGauges',
                request_serializer=osmosis_dot_incentives_dot_query__pb2.UpcomingGaugesRequest.SerializeToString,
                response_deserializer=osmosis_dot_incentives_dot_query__pb2.UpcomingGaugesResponse.FromString,
                )
        self.UpcomingGaugesPerDenom = channel.unary_unary(
                '/osmosis.incentives.Query/UpcomingGaugesPerDenom',
                request_serializer=osmosis_dot_incentives_dot_query__pb2.UpcomingGaugesPerDenomRequest.SerializeToString,
                response_deserializer=osmosis_dot_incentives_dot_query__pb2.UpcomingGaugesPerDenomResponse.FromString,
                )
        self.RewardsEst = channel.unary_unary(
                '/osmosis.incentives.Query/RewardsEst',
                request_serializer=osmosis_dot_incentives_dot_query__pb2.RewardsEstRequest.SerializeToString,
                response_deserializer=osmosis_dot_incentives_dot_query__pb2.RewardsEstResponse.FromString,
                )
        self.LockableDurations = channel.unary_unary(
                '/osmosis.incentives.Query/LockableDurations',
                request_serializer=osmosis_dot_incentives_dot_query__pb2.QueryLockableDurationsRequest.SerializeToString,
                response_deserializer=osmosis_dot_incentives_dot_query__pb2.QueryLockableDurationsResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service
    """

    def ModuleToDistributeCoins(self, request, context):
        """ModuleToDistributeCoins returns coins that are going to be distributed
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GaugeByID(self, request, context):
        """GaugeByID returns gauges by their respective ID
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Gauges(self, request, context):
        """Gauges returns both upcoming and active gauges
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActiveGauges(self, request, context):
        """ActiveGauges returns active gauges
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActiveGaugesPerDenom(self, request, context):
        """ActiveGaugesPerDenom returns active gauges by denom
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpcomingGauges(self, request, context):
        """Returns scheduled gauges that have not yet occured
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpcomingGaugesPerDenom(self, request, context):
        """UpcomingGaugesPerDenom returns scheduled gauges that have not yet occured
        by denom
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RewardsEst(self, request, context):
        """RewardsEst returns an estimate of the rewards from now until a specified
        time in the future The querier either provides an address or a set of locks
        for which they want to find the associated rewards
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LockableDurations(self, request, context):
        """LockableDurations returns lockable durations that are valid to distribute
        incentives for
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ModuleToDistributeCoins': grpc.unary_unary_rpc_method_handler(
                    servicer.ModuleToDistributeCoins,
                    request_deserializer=osmosis_dot_incentives_dot_query__pb2.ModuleToDistributeCoinsRequest.FromString,
                    response_serializer=osmosis_dot_incentives_dot_query__pb2.ModuleToDistributeCoinsResponse.SerializeToString,
            ),
            'GaugeByID': grpc.unary_unary_rpc_method_handler(
                    servicer.GaugeByID,
                    request_deserializer=osmosis_dot_incentives_dot_query__pb2.GaugeByIDRequest.FromString,
                    response_serializer=osmosis_dot_incentives_dot_query__pb2.GaugeByIDResponse.SerializeToString,
            ),
            'Gauges': grpc.unary_unary_rpc_method_handler(
                    servicer.Gauges,
                    request_deserializer=osmosis_dot_incentives_dot_query__pb2.GaugesRequest.FromString,
                    response_serializer=osmosis_dot_incentives_dot_query__pb2.GaugesResponse.SerializeToString,
            ),
            'ActiveGauges': grpc.unary_unary_rpc_method_handler(
                    servicer.ActiveGauges,
                    request_deserializer=osmosis_dot_incentives_dot_query__pb2.ActiveGaugesRequest.FromString,
                    response_serializer=osmosis_dot_incentives_dot_query__pb2.ActiveGaugesResponse.SerializeToString,
            ),
            'ActiveGaugesPerDenom': grpc.unary_unary_rpc_method_handler(
                    servicer.ActiveGaugesPerDenom,
                    request_deserializer=osmosis_dot_incentives_dot_query__pb2.ActiveGaugesPerDenomRequest.FromString,
                    response_serializer=osmosis_dot_incentives_dot_query__pb2.ActiveGaugesPerDenomResponse.SerializeToString,
            ),
            'UpcomingGauges': grpc.unary_unary_rpc_method_handler(
                    servicer.UpcomingGauges,
                    request_deserializer=osmosis_dot_incentives_dot_query__pb2.UpcomingGaugesRequest.FromString,
                    response_serializer=osmosis_dot_incentives_dot_query__pb2.UpcomingGaugesResponse.SerializeToString,
            ),
            'UpcomingGaugesPerDenom': grpc.unary_unary_rpc_method_handler(
                    servicer.UpcomingGaugesPerDenom,
                    request_deserializer=osmosis_dot_incentives_dot_query__pb2.UpcomingGaugesPerDenomRequest.FromString,
                    response_serializer=osmosis_dot_incentives_dot_query__pb2.UpcomingGaugesPerDenomResponse.SerializeToString,
            ),
            'RewardsEst': grpc.unary_unary_rpc_method_handler(
                    servicer.RewardsEst,
                    request_deserializer=osmosis_dot_incentives_dot_query__pb2.RewardsEstRequest.FromString,
                    response_serializer=osmosis_dot_incentives_dot_query__pb2.RewardsEstResponse.SerializeToString,
            ),
            'LockableDurations': grpc.unary_unary_rpc_method_handler(
                    servicer.LockableDurations,
                    request_deserializer=osmosis_dot_incentives_dot_query__pb2.QueryLockableDurationsRequest.FromString,
                    response_serializer=osmosis_dot_incentives_dot_query__pb2.QueryLockableDurationsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'osmosis.incentives.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service
    """

    @staticmethod
    def ModuleToDistributeCoins(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.incentives.Query/ModuleToDistributeCoins',
            osmosis_dot_incentives_dot_query__pb2.ModuleToDistributeCoinsRequest.SerializeToString,
            osmosis_dot_incentives_dot_query__pb2.ModuleToDistributeCoinsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GaugeByID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.incentives.Query/GaugeByID',
            osmosis_dot_incentives_dot_query__pb2.GaugeByIDRequest.SerializeToString,
            osmosis_dot_incentives_dot_query__pb2.GaugeByIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Gauges(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.incentives.Query/Gauges',
            osmosis_dot_incentives_dot_query__pb2.GaugesRequest.SerializeToString,
            osmosis_dot_incentives_dot_query__pb2.GaugesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActiveGauges(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.incentives.Query/ActiveGauges',
            osmosis_dot_incentives_dot_query__pb2.ActiveGaugesRequest.SerializeToString,
            osmosis_dot_incentives_dot_query__pb2.ActiveGaugesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActiveGaugesPerDenom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.incentives.Query/ActiveGaugesPerDenom',
            osmosis_dot_incentives_dot_query__pb2.ActiveGaugesPerDenomRequest.SerializeToString,
            osmosis_dot_incentives_dot_query__pb2.ActiveGaugesPerDenomResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpcomingGauges(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.incentives.Query/UpcomingGauges',
            osmosis_dot_incentives_dot_query__pb2.UpcomingGaugesRequest.SerializeToString,
            osmosis_dot_incentives_dot_query__pb2.UpcomingGaugesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpcomingGaugesPerDenom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.incentives.Query/UpcomingGaugesPerDenom',
            osmosis_dot_incentives_dot_query__pb2.UpcomingGaugesPerDenomRequest.SerializeToString,
            osmosis_dot_incentives_dot_query__pb2.UpcomingGaugesPerDenomResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RewardsEst(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.incentives.Query/RewardsEst',
            osmosis_dot_incentives_dot_query__pb2.RewardsEstRequest.SerializeToString,
            osmosis_dot_incentives_dot_query__pb2.RewardsEstResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LockableDurations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.incentives.Query/LockableDurations',
            osmosis_dot_incentives_dot_query__pb2.QueryLockableDurationsRequest.SerializeToString,
            osmosis_dot_incentives_dot_query__pb2.QueryLockableDurationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ListAllInterfacesRequest(google.protobuf.message.Message):
    """ListAllInterfacesRequest is the request type of the ListAllInterfaces RPC."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListAllInterfacesRequest = ListAllInterfacesRequest

@typing_extensions.final
class ListAllInterfacesResponse(google.protobuf.message.Message):
    """ListAllInterfacesResponse is the response type of the ListAllInterfaces RPC."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTERFACE_NAMES_FIELD_NUMBER: builtins.int
    @property
    def interface_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """interface_names is an array of all the registered interfaces."""
    def __init__(
        self,
        *,
        interface_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["interface_names", b"interface_names"]) -> None: ...

global___ListAllInterfacesResponse = ListAllInterfacesResponse

@typing_extensions.final
class ListImplementationsRequest(google.protobuf.message.Message):
    """ListImplementationsRequest is the request type of the ListImplementations
    RPC.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTERFACE_NAME_FIELD_NUMBER: builtins.int
    interface_name: builtins.str
    """interface_name defines the interface to query the implementations for."""
    def __init__(
        self,
        *,
        interface_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["interface_name", b"interface_name"]) -> None: ...

global___ListImplementationsRequest = ListImplementationsRequest

@typing_extensions.final
class ListImplementationsResponse(google.protobuf.message.Message):
    """ListImplementationsResponse is the response type of the ListImplementations
    RPC.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMPLEMENTATION_MESSAGE_NAMES_FIELD_NUMBER: builtins.int
    @property
    def implementation_message_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        implementation_message_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["implementation_message_names", b"implementation_message_names"]) -> None: ...

global___ListImplementationsResponse = ListImplementationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Since: cosmos-sdk 0.43"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class PubKey(google.protobuf.message.Message):
    """PubKey defines a secp256r1 ECDSA public key."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    key: builtins.bytes
    """Point on secp256r1 curve in a compressed representation as specified in section
    4.3.6 of ANSI X9.62: https://webstore.ansi.org/standards/ascx9/ansix9621998
    """
    def __init__(
        self,
        *,
        key: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key"]) -> None: ...

global___PubKey = PubKey

@typing_extensions.final
class PrivKey(google.protobuf.message.Message):
    """PrivKey defines a secp256r1 ECDSA private key."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_FIELD_NUMBER: builtins.int
    secret: builtins.bytes
    """secret number serialized using big-endian encoding"""
    def __init__(
        self,
        *,
        secret: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret", b"secret"]) -> None: ...

global___PrivKey = PrivKey



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.pool_incentives.v1beta1.incentives_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the pool incentives module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    LOCKABLE_DURATIONS_FIELD_NUMBER: builtins.int
    DISTR_INFO_FIELD_NUMBER: builtins.int
    POOL_TO_GAUGES_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> osmosis.pool_incentives.v1beta1.incentives_pb2.Params:
        """params defines all the paramaters of the module."""
    @property
    def lockable_durations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.duration_pb2.Duration]: ...
    @property
    def distr_info(self) -> osmosis.pool_incentives.v1beta1.incentives_pb2.DistrInfo: ...
    @property
    def pool_to_gauges(self) -> osmosis.pool_incentives.v1beta1.incentives_pb2.PoolToGauges: ...
    def __init__(
        self,
        *,
        params: osmosis.pool_incentives.v1beta1.incentives_pb2.Params | None = ...,
        lockable_durations: collections.abc.Iterable[google.protobuf.duration_pb2.Duration] | None = ...,
        distr_info: osmosis.pool_incentives.v1beta1.incentives_pb2.DistrInfo | None = ...,
        pool_to_gauges: osmosis.pool_incentives.v1beta1.incentives_pb2.PoolToGauges | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["distr_info", b"distr_info", "params", b"params", "pool_to_gauges", b"pool_to_gauges"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["distr_info", b"distr_info", "lockable_durations", b"lockable_durations", "params", b"params", "pool_to_gauges", b"pool_to_gauges"]) -> None: ...

global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MsgSetWithdrawAddress(google.protobuf.message.Message):
    """MsgSetWithdrawAddress sets the withdraw address for
    a delegator (or validator self-delegation).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    WITHDRAW_ADDRESS_FIELD_NUMBER: builtins.int
    delegator_address: builtins.str
    withdraw_address: builtins.str
    def __init__(
        self,
        *,
        delegator_address: builtins.str = ...,
        withdraw_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_address", b"delegator_address", "withdraw_address", b"withdraw_address"]) -> None: ...

global___MsgSetWithdrawAddress = MsgSetWithdrawAddress

@typing_extensions.final
class MsgSetWithdrawAddressResponse(google.protobuf.message.Message):
    """MsgSetWithdrawAddressResponse defines the Msg/SetWithdrawAddress response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgSetWithdrawAddressResponse = MsgSetWithdrawAddressResponse

@typing_extensions.final
class MsgWithdrawDelegatorReward(google.protobuf.message.Message):
    """MsgWithdrawDelegatorReward represents delegation withdrawal to a delegator
    from a single validator.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    delegator_address: builtins.str
    validator_address: builtins.str
    def __init__(
        self,
        *,
        delegator_address: builtins.str = ...,
        validator_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_address", b"delegator_address", "validator_address", b"validator_address"]) -> None: ...

global___MsgWithdrawDelegatorReward = MsgWithdrawDelegatorReward

@typing_extensions.final
class MsgWithdrawDelegatorRewardResponse(google.protobuf.message.Message):
    """MsgWithdrawDelegatorRewardResponse defines the Msg/WithdrawDelegatorReward response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgWithdrawDelegatorRewardResponse = MsgWithdrawDelegatorRewardResponse

@typing_extensions.final
class MsgWithdrawValidatorCommission(google.protobuf.message.Message):
    """MsgWithdrawValidatorCommission withdraws the full commission to the validator
    address.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    validator_address: builtins.str
    def __init__(
        self,
        *,
        validator_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["validator_address", b"validator_address"]) -> None: ...

global___MsgWithdrawValidatorCommission = MsgWithdrawValidatorCommission

@typing_extensions.final
class MsgWithdrawValidatorCommissionResponse(google.protobuf.message.Message):
    """MsgWithdrawValidatorCommissionResponse defines the Msg/WithdrawValidatorCommission response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgWithdrawValidatorCommissionResponse = MsgWithdrawValidatorCommissionResponse

@typing_extensions.final
class MsgFundCommunityPool(google.protobuf.message.Message):
    """MsgFundCommunityPool allows an account to directly
    fund the community pool.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AMOUNT_FIELD_NUMBER: builtins.int
    DEPOSITOR_FIELD_NUMBER: builtins.int
    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    depositor: builtins.str
    def __init__(
        self,
        *,
        amount: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        depositor: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "depositor", b"depositor"]) -> None: ...

global___MsgFundCommunityPool = MsgFundCommunityPool

@typing_extensions.final
class MsgFundCommunityPoolResponse(google.protobuf.message.Message):
    """MsgFundCommunityPoolResponse defines the Msg/FundCommunityPool response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgFundCommunityPoolResponse = MsgFundCommunityPoolResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.pool_incentives.v1beta1.query_pb2

class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GaugeIds: grpc.UnaryUnaryMultiCallable[
        osmosis.pool_incentives.v1beta1.query_pb2.QueryGaugeIdsRequest,
        osmosis.pool_incentives.v1beta1.query_pb2.QueryGaugeIdsResponse,
    ]
    """GaugeIds takes the pool id and returns the matching gauge ids and durations"""
    DistrInfo: grpc.UnaryUnaryMultiCallable[
        osmosis.pool_incentives.v1beta1.query_pb2.QueryDistrInfoRequest,
        osmosis.pool_incentives.v1beta1.query_pb2.QueryDistrInfoResponse,
    ]
    """DistrInfo returns the pool's matching gauge ids and weights."""
    Params: grpc.UnaryUnaryMultiCallable[
        osmosis.pool_incentives.v1beta1.query_pb2.QueryParamsRequest,
        osmosis.pool_incentives.v1beta1.query_pb2.QueryParamsResponse,
    ]
    """Params returns pool incentives params."""
    LockableDurations: grpc.UnaryUnaryMultiCallable[
        osmosis.pool_incentives.v1beta1.query_pb2.QueryLockableDurationsRequest,
        osmosis.pool_incentives.v1beta1.query_pb2.QueryLockableDurationsResponse,
    ]
    """LockableDurations returns lock durations for pools."""
    IncentivizedPools: grpc.UnaryUnaryMultiCallable[
        osmosis.pool_incentives.v1beta1.query_pb2.QueryIncentivizedPoolsRequest,
        osmosis.pool_incentives.v1beta1.query_pb2.QueryIncentivizedPoolsResponse,
    ]
    """IncentivizedPools returns currently incentivized pools"""
    ExternalIncentiveGauges: grpc.UnaryUnaryMultiCallable[
        osmosis.pool_incentives.v1beta1.query_pb2.QueryExternalIncentiveGaugesRequest,
        osmosis.pool_incentives.v1beta1.query_pb2.QueryExternalIncentiveGaugesResponse,
    ]
    """ExternalIncentiveGauges returns external incentive gauges."""

class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GaugeIds(
        self,
        request: osmosis.pool_incentives.v1beta1.query_pb2.QueryGaugeIdsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.pool_incentives.v1beta1.query_pb2.QueryGaugeIdsResponse:
        """GaugeIds takes the pool id and returns the matching gauge ids and durations"""
    @abc.abstractmethod
    def DistrInfo(
        self,
        request: osmosis.pool_incentives.v1beta1.query_pb2.QueryDistrInfoRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.pool_incentives.v1beta1.query_pb2.QueryDistrInfoResponse:
        """DistrInfo returns the pool's matching gauge ids and weights."""
    @abc.abstractmethod
    def Params(
        self,
        request: osmosis.pool_incentives.v1beta1.query_pb2.QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.pool_incentives.v1beta1.query_pb2.QueryParamsResponse:
        """Params returns pool incentives params."""
    @abc.abstractmethod
    def LockableDurations(
        self,
        request: osmosis.pool_incentives.v1beta1.query_pb2.QueryLockableDurationsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.pool_incentives.v1beta1.query_pb2.QueryLockableDurationsResponse:
        """LockableDurations returns lock durations for pools."""
    @abc.abstractmethod
    def IncentivizedPools(
        self,
        request: osmosis.pool_incentives.v1beta1.query_pb2.QueryIncentivizedPoolsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.pool_incentives.v1beta1.query_pb2.QueryIncentivizedPoolsResponse:
        """IncentivizedPools returns currently incentivized pools"""
    @abc.abstractmethod
    def ExternalIncentiveGauges(
        self,
        request: osmosis.pool_incentives.v1beta1.query_pb2.QueryExternalIncentiveGaugesRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.pool_incentives.v1beta1.query_pb2.QueryExternalIncentiveGaugesResponse:
        """ExternalIncentiveGauges returns external incentive gauges."""

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.params.v1beta1.params_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QueryParamsRequest(google.protobuf.message.Message):
    """QueryParamsRequest is request type for the Query/Params RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBSPACE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    subspace: builtins.str
    """subspace defines the module to query the parameter for."""
    key: builtins.str
    """key defines the key of the parameter in the subspace."""
    def __init__(
        self,
        *,
        subspace: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "subspace", b"subspace"]) -> None: ...

global___QueryParamsRequest = QueryParamsRequest

@typing_extensions.final
class QueryParamsResponse(google.protobuf.message.Message):
    """QueryParamsResponse is response type for the Query/Params RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAM_FIELD_NUMBER: builtins.int
    @property
    def param(self) -> cosmos.params.v1beta1.params_pb2.ParamChange:
        """param defines the queried parameter."""
    def __init__(
        self,
        *,
        param: cosmos.params.v1beta1.params_pb2.ParamChange | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["param", b"param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["param", b"param"]) -> None: ...

global___QueryParamsResponse = QueryParamsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/lockup/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from osmosis.lockup import lock_pb2 as osmosis_dot_lockup_dot_lock__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cosmosis/lockup/genesis.proto\x12\x0eosmosis.lockup\x1a\x14gogoproto/gogo.proto\x1a\x19osmosis/lockup/lock.proto\"\x93\x01\n\x0cGenesisState\x12\x14\n\x0clast_lock_id\x18\x01 \x01(\x04\x12/\n\x05locks\x18\x02 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLockB\x04\xc8\xde\x1f\x00\x12<\n\x0fsynthetic_locks\x18\x03 \x03(\x0b\x32\x1d.osmosis.lockup.SyntheticLockB\x04\xc8\xde\x1f\x00\x42\x34Z2github.com/osmosis-labs/osmosis/v14/x/lockup/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.lockup.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/osmosis-labs/osmosis/v14/x/lockup/types'
  _GENESISSTATE.fields_by_name['locks']._options = None
  _GENESISSTATE.fields_by_name['locks']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['synthetic_locks']._options = None
  _GENESISSTATE.fields_by_name['synthetic_locks']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE._serialized_start=98
  _GENESISSTATE._serialized_end=245
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class EpochInfo(google.protobuf.message.Message):
    """EpochInfo is a struct that describes the data going into
    a timer defined by the x/epochs module.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    CURRENT_EPOCH_FIELD_NUMBER: builtins.int
    CURRENT_EPOCH_START_TIME_FIELD_NUMBER: builtins.int
    EPOCH_COUNTING_STARTED_FIELD_NUMBER: builtins.int
    CURRENT_EPOCH_START_HEIGHT_FIELD_NUMBER: builtins.int
    identifier: builtins.str
    """identifier is a unique reference to this particular timer."""
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """start_time is the time at which the timer first ever ticks.
        If start_time is in the future, the epoch will not begin until the start
        time.
        """
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """duration is the time in between epoch ticks.
        In order for intended behavior to be met, duration should
        be greater than the chains expected block time.
        Duration must be non-zero.
        """
    current_epoch: builtins.int
    """current_epoch is the current epoch number, or in other words,
    how many times has the timer 'ticked'.
    The first tick (current_epoch=1) is defined as
    the first block whose blocktime is greater than the EpochInfo start_time.
    """
    @property
    def current_epoch_start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """current_epoch_start_time describes the start time of the current timer
        interval. The interval is (current_epoch_start_time,
        current_epoch_start_time + duration] When the timer ticks, this is set to
        current_epoch_start_time = last_epoch_start_time + duration only one timer
        tick for a given identifier can occur per block.

        NOTE! The current_epoch_start_time may diverge significantly from the
        wall-clock time the epoch began at. Wall-clock time of epoch start may be
        >> current_epoch_start_time. Suppose current_epoch_start_time = 10,
        duration = 5. Suppose the chain goes offline at t=14, and comes back online
        at t=30, and produces blocks at every successive time. (t=31, 32, etc.)
        * The t=30 block will start the epoch for (10, 15]
        * The t=31 block will start the epoch for (15, 20]
        * The t=32 block will start the epoch for (20, 25]
        * The t=33 block will start the epoch for (25, 30]
        * The t=34 block will start the epoch for (30, 35]
        * The **t=36** block will start the epoch for (35, 40]
        """
    epoch_counting_started: builtins.bool
    """epoch_counting_started is a boolean, that indicates whether this
    epoch timer has began yet.
    """
    current_epoch_start_height: builtins.int
    """current_epoch_start_height is the block height at which the current epoch
    started. (The block height at which the timer last ticked)
    """
    def __init__(
        self,
        *,
        identifier: builtins.str = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
        current_epoch: builtins.int = ...,
        current_epoch_start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        epoch_counting_started: builtins.bool = ...,
        current_epoch_start_height: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["current_epoch_start_time", b"current_epoch_start_time", "duration", b"duration", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["current_epoch", b"current_epoch", "current_epoch_start_height", b"current_epoch_start_height", "current_epoch_start_time", b"current_epoch_start_time", "duration", b"duration", "epoch_counting_started", b"epoch_counting_started", "identifier", b"identifier", "start_time", b"start_time"]) -> None: ...

global___EpochInfo = EpochInfo

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the epochs module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPOCHS_FIELD_NUMBER: builtins.int
    @property
    def epochs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EpochInfo]: ...
    def __init__(
        self,
        *,
        epochs: collections.abc.Iterable[global___EpochInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["epochs", b"epochs"]) -> None: ...

global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.txfees.v1beta1.feetoken_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QueryFeeTokensRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryFeeTokensRequest = QueryFeeTokensRequest

@typing_extensions.final
class QueryFeeTokensResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEE_TOKENS_FIELD_NUMBER: builtins.int
    @property
    def fee_tokens(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.txfees.v1beta1.feetoken_pb2.FeeToken]: ...
    def __init__(
        self,
        *,
        fee_tokens: collections.abc.Iterable[osmosis.txfees.v1beta1.feetoken_pb2.FeeToken] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fee_tokens", b"fee_tokens"]) -> None: ...

global___QueryFeeTokensResponse = QueryFeeTokensResponse

@typing_extensions.final
class QueryDenomSpotPriceRequest(google.protobuf.message.Message):
    """QueryDenomSpotPriceRequest defines grpc request structure for querying spot
    price for the specified tx fee denom
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    denom: builtins.str
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom", b"denom"]) -> None: ...

global___QueryDenomSpotPriceRequest = QueryDenomSpotPriceRequest

@typing_extensions.final
class QueryDenomSpotPriceResponse(google.protobuf.message.Message):
    """QueryDenomSpotPriceRequest defines grpc response structure for querying spot
    price for the specified tx fee denom
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOLID_FIELD_NUMBER: builtins.int
    SPOT_PRICE_FIELD_NUMBER: builtins.int
    poolID: builtins.int
    spot_price: builtins.str
    def __init__(
        self,
        *,
        poolID: builtins.int = ...,
        spot_price: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["poolID", b"poolID", "spot_price", b"spot_price"]) -> None: ...

global___QueryDenomSpotPriceResponse = QueryDenomSpotPriceResponse

@typing_extensions.final
class QueryDenomPoolIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    denom: builtins.str
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom", b"denom"]) -> None: ...

global___QueryDenomPoolIdRequest = QueryDenomPoolIdRequest

@typing_extensions.final
class QueryDenomPoolIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOLID_FIELD_NUMBER: builtins.int
    poolID: builtins.int
    def __init__(
        self,
        *,
        poolID: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["poolID", b"poolID"]) -> None: ...

global___QueryDenomPoolIdResponse = QueryDenomPoolIdResponse

@typing_extensions.final
class QueryBaseDenomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryBaseDenomRequest = QueryBaseDenomRequest

@typing_extensions.final
class QueryBaseDenomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_DENOM_FIELD_NUMBER: builtins.int
    base_denom: builtins.str
    def __init__(
        self,
        *,
        base_denom: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_denom", b"base_denom"]) -> None: ...

global___QueryBaseDenomResponse = QueryBaseDenomResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/ibc-rate-limit/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google_apis.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from osmosis.ibc_rate_limit.v1beta1 import params_pb2 as osmosis_dot_ibc__rate__limit_dot_v1beta1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*osmosis/ibc-rate-limit/v1beta1/query.proto\x12\x1cosmosis.ibcratelimit.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a+osmosis/ibc-rate-limit/v1beta1/params.proto\"\x0f\n\rParamsRequest\"L\n\x0eParamsResponse\x12:\n\x06params\x18\x01 \x01(\x0b\x32$.osmosis.ibcratelimit.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x32\x9d\x01\n\x05Query\x12\x93\x01\n\x06Params\x12+.osmosis.ibcratelimit.v1beta1.ParamsRequest\x1a,.osmosis.ibcratelimit.v1beta1.ParamsResponse\".\x82\xd3\xe4\x93\x02(\x12&/osmosis/ibc-rate-limit/v1beta1/paramsBHZFgithub.com/osmosis-labs/osmosis/v14/x/ibc-rate-limit/client/queryprotob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.ibc_rate_limit.v1beta1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZFgithub.com/osmosis-labs/osmosis/v14/x/ibc-rate-limit/client/queryproto'
  _PARAMSRESPONSE.fields_by_name['params']._options = None
  _PARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002(\022&/osmosis/ibc-rate-limit/v1beta1/params'
  _PARAMSREQUEST._serialized_start=217
  _PARAMSREQUEST._serialized_end=232
  _PARAMSRESPONSE._serialized_start=234
  _PARAMSRESPONSE._serialized_end=310
  _QUERY._serialized_start=313
  _QUERY._serialized_end=470
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from cosmos.vesting.v1beta1 import tx_pb2 as cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the bank Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateVestingAccount = channel.unary_unary(
                '/cosmos.vesting.v1beta1.Msg/CreateVestingAccount',
                request_serializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateVestingAccount.SerializeToString,
                response_deserializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateVestingAccountResponse.FromString,
                )
        self.CreateClawbackVestingAccount = channel.unary_unary(
                '/cosmos.vesting.v1beta1.Msg/CreateClawbackVestingAccount',
                request_serializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateClawbackVestingAccount.SerializeToString,
                response_deserializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateClawbackVestingAccountResponse.FromString,
                )
        self.Clawback = channel.unary_unary(
                '/cosmos.vesting.v1beta1.Msg/Clawback',
                request_serializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgClawback.SerializeToString,
                response_deserializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgClawbackResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the bank Msg service.
    """

    def CreateVestingAccount(self, request, context):
        """CreateVestingAccount defines a method that enables creating a vesting
        account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateClawbackVestingAccount(self, request, context):
        """CreateClawbackVestingAccount creats a vesting account that is subject to
        clawback and the configuration of vesting and lockup schedules.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Clawback(self, request, context):
        """Clawback removes the unvested tokens from a ClawbackVestingAccount.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateVestingAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateVestingAccount,
                    request_deserializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateVestingAccount.FromString,
                    response_serializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateVestingAccountResponse.SerializeToString,
            ),
            'CreateClawbackVestingAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateClawbackVestingAccount,
                    request_deserializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateClawbackVestingAccount.FromString,
                    response_serializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateClawbackVestingAccountResponse.SerializeToString,
            ),
            'Clawback': grpc.unary_unary_rpc_method_handler(
                    servicer.Clawback,
                    request_deserializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgClawback.FromString,
                    response_serializer=cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgClawbackResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.vesting.v1beta1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the bank Msg service.
    """

    @staticmethod
    def CreateVestingAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.vesting.v1beta1.Msg/CreateVestingAccount',
            cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateVestingAccount.SerializeToString,
            cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateVestingAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateClawbackVestingAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.vesting.v1beta1.Msg/CreateClawbackVestingAccount',
            cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateClawbackVestingAccount.SerializeToString,
            cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgCreateClawbackVestingAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Clawback(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.vesting.v1beta1.Msg/Clawback',
            cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgClawback.SerializeToString,
            cosmos_dot_vesting_dot_v1beta1_dot_tx__pb2.MsgClawbackResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the crisis module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSTANT_FEE_FIELD_NUMBER: builtins.int
    @property
    def constant_fee(self) -> cosmos.base.v1beta1.coin_pb2.Coin:
        """constant_fee is the fee used to verify the invariant in the crisis
        module.
        """
    def __init__(
        self,
        *,
        constant_fee: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["constant_fee", b"constant_fee"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["constant_fee", b"constant_fee"]) -> None: ...

global___GenesisState = GenesisState
